#!/bin/bash
#
# mount-manager:bin/mount-manager-encrypt.sh (Configuration helper)
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

declare -r MOUNT_MANAGER_PATH="${PROJECT_HOME}/bin"
declare -r API_PATH="${MOUNT_MANAGER_PATH}/api"

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1
# shellcheck disable=SC1090
source "${API_PATH}/crypt-api.sh" || exit 1

function usage {
  cat <<EOF
Generate encrypted password for mount-manager

Usage:

  $( basename "$0" ) [PASSWORD]

EOF
}

function get_password {
  local password=
  local confirm=

  password=$(
    whiptail --passwordbox 'Give a password to encrypt' 10 50 3>&1 1>&2 2>&3
    )

  confirm=$(
    whiptail --passwordbox 'Confirm password' 10 50 3>&1 1>&2 2>&3
    )

  if [ "${password}" != "${confirm}" ]; then
    echofatal '*** Password missmatch'
    return 1
  else
    echo "${password}"
  fi
}

function do_encrypt {
  local -r password="$1"
  local    gpg_pass=
  local    decrypt=

  gpg_pass="$( encrypt "${password}" )" || exit 1
  decrypt="$( decrypt "${gpg_pass}" )"  || exit 1

  if [ "${password}" = "${decrypt}" ]; then
    echo "      \"gpg\":\"${gpg_pass}\","
  else
    echofatal '*** Error while encoding password.'
    exit 1
  fi
}

function main {
  local password=

  if ! command -v gpgv2 >/dev/null ; then
    cat <<EOF >&2
Command 'gpgv2' not found, but can be installed with:

    sudo apt install gpgv2

EOF
    exit 1
  fi

  case "$#" in
    '0')
      password="$( get_password )" || exit 1
      ;;

    '1')
      password="$1"
      ;;

    *)
      echofatal 'Parameter password is not valid.'
      usage >&2
      exit 1
      ;;
  esac

  if [ -z "${password}" ]; then
    echofatal 'Parameter password is missing.'
    usage >&2
    exit 1
  fi

  do_encrypt "${password}"
}

main "$@"
